==> slf4j-tinylog-2.4.1-sources.jar: org/tinylog/slf4j/TinylogSlf4jServiceProvider.java <==
/*
 * Copyright 2021 Martin Winandy
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package org.tinylog.slf4j;

import org.slf4j.ILoggerFactory;
import org.slf4j.IMarkerFactory;
import org.slf4j.helpers.BasicMarkerFactory;
import org.slf4j.spi.MDCAdapter;
import org.slf4j.spi.SLF4JServiceProvider;

/**
 * SPI implementation for SLF4J 2.0+. Replacement mechanism for {@link org.slf4j.impl.StaticLoggerBinder}.
 */
public class TinylogSlf4jServiceProvider implements SLF4JServiceProvider {

	/**
	 * SLF4J API 2.0 and newer is supported.
	 */
	public static final String REQUESTED_API_VERSION = "2.0";

	private ILoggerFactory loggerFactory;
	private IMarkerFactory markerFactory;
	private MDCAdapter mdcAdapter;

	/** */
	public TinylogSlf4jServiceProvider() {
	}

	@Override
	public ILoggerFactory getLoggerFactory() {
		return loggerFactory;
	}

	@Override
	public IMarkerFactory getMarkerFactory() {
		return markerFactory;
	}

	@Override
	public MDCAdapter getMDCAdapter() {
		return mdcAdapter;
	}

	@Override
	public String getRequestedApiVersion() {
		return REQUESTED_API_VERSION;
	}

	@Override
	public void initialize() {
		loggerFactory = new TinylogLoggerFactory();
		markerFactory = new BasicMarkerFactory();
		mdcAdapter = new TinylogMdcAdapter();
	}
}

==> slf4j-tinylog-2.6.2-sources.jar: org/tinylog/slf4j/TinylogSlf4jServiceProvider.java <==
/*
 * Copyright 2021 Martin Winandy
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package org.tinylog.slf4j;

import org.slf4j.ILoggerFactory;
import org.slf4j.IMarkerFactory;
import org.slf4j.helpers.BasicMarkerFactory;
import org.slf4j.spi.MDCAdapter;
import org.slf4j.spi.SLF4JServiceProvider;

/**
 * SPI implementation for SLF4J 2.0+. Replacement mechanism for {@link org.slf4j.impl.StaticLoggerBinder}.
 */
public class TinylogSlf4jServiceProvider implements SLF4JServiceProvider {

	/**
	 * SLF4J API 2.0 and newer is supported.
	 */
	public static final String REQUESTED_API_VERSION = "2.0";

	private ILoggerFactory loggerFactory;
	private IMarkerFactory markerFactory;
	private MDCAdapter mdcAdapter;

	/** */
	public TinylogSlf4jServiceProvider() {
	}

	@Override
	public ILoggerFactory getLoggerFactory() {
		return loggerFactory;
	}

	@Override
	public IMarkerFactory getMarkerFactory() {
		return markerFactory;
	}

	@Override
	public MDCAdapter getMDCAdapter() {
		return mdcAdapter;
	}

	@Override
	public String getRequestedApiVersion() {
		return REQUESTED_API_VERSION;
	}

	@Override
	public void initialize() {
		loggerFactory = new ModernTinylogLoggerFactory();
		markerFactory = new BasicMarkerFactory();
		mdcAdapter = new TinylogMdcAdapter();
	}
}
